@@ -40,4 +40,7 @@ class AsyncMigrationStatus(models.Model):
     status = models.CharField(max_length=100, choices=STATUS_CHOICES, null=True, default=None)
 
     created_at = models.DateTimeField(_('created at'), auto_now_add=True, help_text='Creation time')
-    updated_at = models.DateTimeField(_('updated at'), auto_now=True, help_text='Last updated time')
\ No newline at end of file
+    updated_at = models.DateTimeField(_('updated at'), auto_now=True, help_text='Last updated time')
+
+    def __str__(self):
+        return f'(id={self.id}) ' + self.name + (' at project ' + str(self.project) if self.project else '')
\ No newline at end of file
