@@ -35,7 +35,7 @@ class AnnotationSerializer(FlexFieldsModelSerializer):
     def get_result(self, obj):
         # run frames extraction on param, result and result type
         if obj.result and self.context.get('interpolate_key_frames', False) and \
-                is_video_object_tracking(parsed_config=obj.task.project.get_parsed_config()):
+                is_video_object_tracking(parsed_config=obj.project.get_parsed_config()):
             return extract_key_frames(obj.result)
         return obj.result
 
@@ -48,7 +48,12 @@ class BaseExportDataSerializer(FlexFieldsModelSerializer):
 
     # resolve $undefined$ key in task data, if any
     def to_representation(self, task):
-        project = task.project
+        # avoid long project initializations
+        project = getattr(self, '_project', None)
+        if project is None:
+            project = task.project
+            setattr(self, '_project', project)
+
         data = task.data
         # add interpolate_key_frames param to annotations serializer
         if 'annotations' in self.fields:
