@@ -11,9 +11,22 @@ uri_regex = r"([\"'])(?P<uri>(?P<storage>{})://[^\1=]*)\1"
 
 def get_uri_via_regex(data, prefixes=('s3', 'gs')):
     data = str(data).strip()
+    middle_check = False
+
+    # make the fastest startswith check first
     for prefix in prefixes:
         if data.startswith(prefix):
             return data, prefix
+
+        # another fast middle-check before regex run
+        if prefix + ':' in data:
+            middle_check = True
+
+    # no prefixes in data, exit
+    if middle_check is False:
+        return None, None
+
+    # make complex regex check for data like <a href="s3://test/123.jpg">
     try:
         uri_regex_prepared = uri_regex.format('|'.join(prefixes))
         r_match = re.search(uri_regex_prepared, data)
