@@ -14,16 +14,15 @@ from rest_framework.parsers import FormParser, JSONParser, MultiPartParser
 from rest_framework.response import Response
 
 from core.permissions import ViewClassPermission, all_permissions
-from core.utils.common import (
-    DjangoFilterDescriptionInspector,
-    get_object_with_check_and_log,
-)
+from core.utils.common import DjangoFilterDescriptionInspector
 from core.utils.params import bool_from_request
+from core.mixins import GetParentObjectMixin
 from data_manager.api import TaskListAPI as DMTaskListAPI
 from data_manager.functions import evaluate_predictions
 from data_manager.models import PrepareParams
 from data_manager.serializers import DataManagerTaskSerializer
 from projects.models import Project
+from projects.functions.stream_history import fill_history_annotation
 from tasks.models import Annotation, AnnotationDraft, Prediction, Task
 from tasks.serializers import (
     AnnotationDraftSerializer,
@@ -65,6 +64,11 @@ logger = logging.getLogger(__name__)
             type=openapi.TYPE_INTEGER,
             in_=openapi.IN_QUERY,
             description='Project ID'),
+        openapi.Parameter(
+            name='resolve_uri',
+            type=openapi.TYPE_BOOLEAN,
+            in_=openapi.IN_QUERY,
+            description='Resolve task data URIs using Cloud Storage'),
     ],
 ))
 class TaskListAPI(DMTaskListAPI):
@@ -74,7 +78,7 @@ class TaskListAPI(DMTaskListAPI):
         POST=all_permissions.tasks_create,
     )
     filter_backends = [DjangoFilterBackend]
-    filterset_fields = ['project',]
+    filterset_fields = ['project']
 
     def filter_queryset(self, queryset):
         queryset = super().filter_queryset(queryset)
@@ -182,6 +186,8 @@ class TaskAPI(generics.RetrieveUpdateDestroyAPIView):
         return Response(data)
 
     def get_queryset(self):
+        task_id = self.request.parser_context['kwargs'].get('pk')
+        task = generics.get_object_or_404(Task, pk=task_id)
         review = bool_from_request(self.request.GET, 'review', False)
         selected = {"all": False, "included": [self.kwargs.get("pk")]}
         if review:
@@ -192,7 +198,7 @@ class TaskAPI(generics.RetrieveUpdateDestroyAPIView):
             kwargs = {'all_fields': True}
         project = self.request.query_params.get('project') or self.request.data.get('project')
         if not project:
-            project = Task.objects.get(id=self.request.parser_context['kwargs'].get('pk')).project.id
+            project = task.project.id
         return self.prefetch(
             Task.prepared.get_queryset(
                 prepare_params=PrepareParams(project=project, selectedItems=selected, request=self.request),
@@ -267,8 +273,9 @@ class AnnotationAPI(generics.RetrieveUpdateDestroyAPIView):
 
     def update(self, request, *args, **kwargs):
         # save user history with annotator_id, time & annotation result
-        annotation_id = self.kwargs['pk']
-        annotation = get_object_with_check_and_log(request, Annotation, pk=annotation_id)
+        annotation = self.get_object()
+        # use updated instead of save to avoid duplicated signals
+        Annotation.objects.filter(id=annotation.id).update(updated_by=request.user)
 
         task = annotation.task
         if self.request.data.get('ground_truth'):
@@ -339,12 +346,13 @@ class AnnotationAPI(generics.RetrieveUpdateDestroyAPIView):
         ],
         request_body=AnnotationSerializer
         ))
-class AnnotationsListAPI(generics.ListCreateAPIView):
+class AnnotationsListAPI(GetParentObjectMixin, generics.ListCreateAPIView):
     parser_classes = (JSONParser, FormParser, MultiPartParser)
     permission_required = ViewClassPermission(
         GET=all_permissions.annotations_view,
         POST=all_permissions.annotations_create,
     )
+    parent_queryset = Task.objects.all()
 
     serializer_class = AnnotationSerializer
 
@@ -363,7 +371,7 @@ class AnnotationsListAPI(generics.ListCreateAPIView):
         return AnnotationDraft.objects.filter(id=draft_id).delete()
 
     def perform_create(self, ser):
-        task = get_object_with_check_and_log(self.request, Task, pk=self.kwargs['pk'])
+        task = self.get_parent_object()
         # annotator has write access only to annotations and it can't be checked it after serializer.save()
         user = self.request.user
 
@@ -384,6 +392,7 @@ class AnnotationsListAPI(generics.ListCreateAPIView):
             # serialize annotation
             extra_args.update({
                 'prediction': prediction_ser,
+                'updated_by': user
             })
 
         if 'was_cancelled' in self.request.GET:
@@ -412,6 +421,8 @@ class AnnotationsListAPI(generics.ListCreateAPIView):
         if self.request.data.get('ground_truth'):
             annotation.task.ensure_unique_groundtruth(annotation_id=annotation.id)
 
+        fill_history_annotation(user, task, annotation)
+
         return annotation
 
 
@@ -525,24 +536,27 @@ class PredictionAPI(viewsets.ModelViewSet):
         return Prediction.objects.filter(task__project__organization=self.request.user.active_organization)
 
 
+@method_decorator(name='get', decorator=swagger_auto_schema(auto_schema=None))
 @method_decorator(name='post', decorator=swagger_auto_schema(
         tags=['Annotations'],
         operation_summary='Convert annotation to draft',
         operation_description='Convert annotation to draft',
         ))
-class AnnotationConvertAPI(views.APIView):
+class AnnotationConvertAPI(generics.RetrieveAPIView):
     permission_required = ViewClassPermission(
         POST=all_permissions.annotations_change
     )
+    queryset = Annotation.objects.all()
 
     def process_intermediate_state(self, annotation, draft):
         pass
 
     @swagger_auto_schema(auto_schema=None)
     def post(self, request, *args, **kwargs):
-        annotation = get_object_with_check_and_log(request, Annotation, pk=self.kwargs['pk'])
-        organization = annotation.task.project.organization
-        project = annotation.task.project
+        annotation = self.get_object()
+        organization = annotation.project.organization
+        project = annotation.project
+
         pk = annotation.pk
 
         with transaction.atomic():
