@@ -128,6 +128,10 @@ class UserAPI(viewsets.ModelViewSet):
     def create(self, request, *args, **kwargs):
         return super(UserAPI, self).create(request, *args, **kwargs)
 
+    def perform_create(self, serializer):
+        instance = serializer.save()
+        self.request.user.active_organization.add_user(instance)
+
     def retrieve(self, request, *args, **kwargs):
         return super(UserAPI, self).retrieve(request, *args, **kwargs)
 
